@@ -1,6 +1,6 @@
 /**
  * commons.c -- holds different data types
- * Copyright (C) 2009-2013 by Gerardo Orellana <goaccess@prosoftcorp.com>
+ * Copyright (C) 2009-2014 by Gerardo Orellana <goaccess@prosoftcorp.com>
  * GoAccess - An Ncurses apache weblog analyzer & interactive viewer
  *
  * This program is free software; you can redistribute it and/or
@@ -23,23 +23,48 @@
 #include <config.h>
 #endif
 
-#ifdef HAVE_LIBNCURSESW
-#include <ncursesw/curses.h>
-#else
+#ifdef HAVE_NCURSESW_NCURSES_H
+#include <ncursesw/ncurses.h>
+#elif HAVE_NCURSES_NCURSES_H
+#include <ncurses/ncurses.h>
+#elif HAVE_NCURSES_H
 #include <ncurses.h>
+#elif HAVE_CURSES_H
+#include <curses.h>
 #endif
 
-#include <glib.h>
 #include <time.h>
 
 #include "commons.h"
+#include "error.h"
+#include "settings.h"
+#include "util.h"
 
 /* processing time */
 time_t end_proc;
-time_t now;
+time_t timestamp;
 time_t start_proc;
 
 /* resizing/scheme */
 size_t real_size_y = 0;
 size_t term_h = 0;
 size_t term_w = 0;
+
+/* calculate hits percentage */
+float
+get_percentage (unsigned long long total, unsigned long long hit)
+{
+  return ((float) (hit * 100) / (total));
+}
+
+void
+display_storage (void)
+{
+#ifdef TCB_BTREE
+  fprintf (stdout, "Built using Tokyo Cabinet On-Disk B+ Tree.\n");
+#elif TCB_MEMHASH
+  fprintf (stdout, "Built using Tokyo Cabinet On-Memory Hash database.\n");
+#else
+  fprintf (stdout, "Built using GLib On-Memory Hash database.\n");
+#endif
+}
