@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2009-2013 by Gerardo Orellana <goaccess@prosoftcorp.com>
+ * Copyright (C) 2009-2014 by Gerardo Orellana <goaccess@prosoftcorp.com>
  * GoAccess - An Ncurses apache weblog analyzer & interactive viewer
  *
  * This program is free software; you can redistribute it and/or
@@ -25,6 +25,10 @@
 #include "commons.h"
 #endif
 
-void error_handler (const char *func, char *file, int line, char *msg);
+void dbg_fprintf (const char *fmt, ...);
+void dbg_log_close (void);
+void dbg_log_open (const char *file);
+void error_handler (const char *func, const char *file, int line,
+                    const char *msg, ...);
 
 #endif
