@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2009-2013 by Gerardo Orellana <goaccess@prosoftcorp.com>
+ * Copyright (C) 2009-2014 by Gerardo Orellana <goaccess@prosoftcorp.com>
  * GoAccess - An Ncurses apache weblog analyzer & interactive viewer
  *
  * This program is free software; you can redistribute it and/or
@@ -25,11 +25,11 @@
 #ifndef OUTPUT_H_INCLUDED
 #define OUTPUT_H_INCLUDED
 
-#define OUTPUT_N        10
+#define OUTPUT_N  10
+#define REF_LEN   20
 
-#include "gdashboard.h"
+#include "commons.h"
 #include "parser.h"
-#include "settings.h"
 
 void output_html (GLog * logger, GHolder * holder);
 
